==> brmo-stufbg204-1.6.3p1-sources.jar: nl/egem/stuf/sector/bg/_0204/Relatie.java <==

package nl.egem.stuf.sector.bg._0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import nl.egem.stuf.stuf0204.ExtraElementen;
import nl.egem.stuf.stuf0204.NoValue;
import nl.egem.stuf.stuf0204.TijdvakGeldigheid;
import nl.egem.stuf.stuf0204.TijdvakRelatie;
import nl.egem.stuf.stuf0204.Verwerkingssoort;


/**
 * generieke relatie-entiteit zonder elementen
 * 
 * <p>Java class for Relatie complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="Relatie">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="tijdvakRelatie" type="{http://www.egem.nl/StUF/StUF0204}TijdvakRelatie" minOccurs="0"/>
 *         &lt;element name="tijdvakGeldigheid" type="{http://www.egem.nl/StUF/StUF0204}TijdvakGeldigheid" minOccurs="0"/>
 *         &lt;element name="extraElementen" type="{http://www.egem.nl/StUF/StUF0204}ExtraElementen" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}relatie"/>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Relatie", propOrder = {
    "tijdvakRelatie",
    "tijdvakGeldigheid",
    "extraElementen"
})
@XmlSeeAlso({
    nl.egem.stuf.sector.bg._0204.HHDAntwoord.HDDWOZ.class,
    nl.egem.stuf.sector.bg._0204.WOZKennisgeving.WOZKDO.class,
    nl.egem.stuf.sector.bg._0204.WOZKennisgeving.WOZOBW.class,
    nl.egem.stuf.sector.bg._0204.WOZKennisgeving.WOZSUBEIG.class,
    nl.egem.stuf.sector.bg._0204.WOZKennisgeving.WOZSUBGBR.class,
    nl.egem.stuf.sector.bg._0204.WOZKennisgeving.WOZVBO.class,
    nl.egem.stuf.sector.bg._0204.NNPVraag.NNPNNPHFD.class,
    nl.egem.stuf.sector.bg._0204.NNPVraag.NNPNNPNVN.class,
    nl.egem.stuf.sector.bg._0204.NNPAntwoord.NNPNNPHFD.class,
    nl.egem.stuf.sector.bg._0204.NNPAntwoord.NNPNNPNVN.class,
    nl.egem.stuf.sector.bg._0204.OBWKennisgeving.OBWKDO.class,
    nl.egem.stuf.sector.bg._0204.OBWKennisgeving.OBWBSG.class,
    ADRRelFund.class,
    nl.egem.stuf.sector.bg._0204.HHDKennisgeving.HDDWOZ.class,
    nl.egem.stuf.sector.bg._0204.VBOKennisgeving.VBOBSG.class,
    nl.egem.stuf.sector.bg._0204.VBOKennisgeving.VBOKDO.class,
    nl.egem.stuf.sector.bg._0204.VBOKennisgeving.VBOSUBGBR.class,
    nl.egem.stuf.sector.bg._0204.OBWVraag.OBWKDO.class,
    nl.egem.stuf.sector.bg._0204.OBWVraag.OBWBSG.class,
    nl.egem.stuf.sector.bg._0204.WOZVraag.WOZKDO.class,
    nl.egem.stuf.sector.bg._0204.WOZVraag.WOZOBW.class,
    nl.egem.stuf.sector.bg._0204.WOZVraag.WOZSUBEIG.class,
    nl.egem.stuf.sector.bg._0204.WOZVraag.WOZSUBGBR.class,
    nl.egem.stuf.sector.bg._0204.WOZVraag.WOZVBO.class,
    nl.egem.stuf.sector.bg._0204.KDOAntwoord.KDOBSG.class,
    nl.egem.stuf.sector.bg._0204.KDOAntwoord.KDOPRB.class,
    nl.egem.stuf.sector.bg._0204.KDOAntwoord.KDOSUBVZG.class,
    nl.egem.stuf.sector.bg._0204.KDOKennisgeving.KDOBSG.class,
    nl.egem.stuf.sector.bg._0204.KDOKennisgeving.KDOPRB.class,
    nl.egem.stuf.sector.bg._0204.KDOKennisgeving.KDOSUBVZG.class,
    nl.egem.stuf.sector.bg._0204.VBOVraag.VBOBSG.class,
    nl.egem.stuf.sector.bg._0204.VBOVraag.VBOKDO.class,
    nl.egem.stuf.sector.bg._0204.VBOVraag.VBOSUBGBR.class,
    nl.egem.stuf.sector.bg._0204.HHDVraag.HDDWOZ.class,
    nl.egem.stuf.sector.bg._0204.NNPKennisgeving.NNPNNPHFD.class,
    nl.egem.stuf.sector.bg._0204.NNPKennisgeving.NNPNNPNVN.class,
    nl.egem.stuf.sector.bg._0204.VBOAntwoord.VBOBSG.class,
    nl.egem.stuf.sector.bg._0204.VBOAntwoord.VBOKDO.class,
    nl.egem.stuf.sector.bg._0204.VBOAntwoord.VBOSUBGBR.class,
    nl.egem.stuf.sector.bg._0204.WOZAntwoord.WOZKDO.class,
    nl.egem.stuf.sector.bg._0204.WOZAntwoord.WOZOBW.class,
    nl.egem.stuf.sector.bg._0204.WOZAntwoord.WOZSUBEIG.class,
    nl.egem.stuf.sector.bg._0204.WOZAntwoord.WOZSUBGBR.class,
    nl.egem.stuf.sector.bg._0204.WOZAntwoord.WOZVBO.class,
    ADRRelKerngegevens.class,
    nl.egem.stuf.sector.bg._0204.KDOVraag.KDOBSG.class,
    nl.egem.stuf.sector.bg._0204.KDOVraag.KDOPRB.class,
    nl.egem.stuf.sector.bg._0204.KDOVraag.KDOSUBVZG.class,
    nl.egem.stuf.sector.bg._0204.OBWAntwoord.OBWKDO.class,
    nl.egem.stuf.sector.bg._0204.OBWAntwoord.OBWBSG.class
})
public class Relatie {

    protected TijdvakRelatie tijdvakRelatie;
    protected TijdvakGeldigheid tijdvakGeldigheid;
    protected ExtraElementen extraElementen;
    @XmlAttribute(name = "soortEntiteit", required = true)
    protected String soortEntiteit;
    @XmlAttribute(name = "sleutelVerzendend", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected String sleutelVerzendend;
    @XmlAttribute(name = "sleutelOntvangend", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected String sleutelOntvangend;
    @XmlAttribute(name = "sleutelGegevensbeheer", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected String sleutelGegevensbeheer;
    @XmlAttribute(name = "verwerkingssoort", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected Verwerkingssoort verwerkingssoort;
    @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected NoValue noValue;

    /**
     * Gets the value of the tijdvakRelatie property.
     * 
     * @return
     *     possible object is
     *     {@link TijdvakRelatie }
     *     
     */
    public TijdvakRelatie getTijdvakRelatie() {
        return tijdvakRelatie;
    }

    /**
     * Sets the value of the tijdvakRelatie property.
     * 
     * @param value
     *     allowed object is
     *     {@link TijdvakRelatie }
     *     
     */
    public void setTijdvakRelatie(TijdvakRelatie value) {
        this.tijdvakRelatie = value;
    }

    /**
     * Gets the value of the tijdvakGeldigheid property.
     * 
     * @return
     *     possible object is
     *     {@link TijdvakGeldigheid }
     *     
     */
    public TijdvakGeldigheid getTijdvakGeldigheid() {
        return tijdvakGeldigheid;
    }

    /**
     * Sets the value of the tijdvakGeldigheid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TijdvakGeldigheid }
     *     
     */
    public void setTijdvakGeldigheid(TijdvakGeldigheid value) {
        this.tijdvakGeldigheid = value;
    }

    /**
     * Gets the value of the extraElementen property.
     * 
     * @return
     *     possible object is
     *     {@link ExtraElementen }
     *     
     */
    public ExtraElementen getExtraElementen() {
        return extraElementen;
    }

    /**
     * Sets the value of the extraElementen property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtraElementen }
     *     
     */
    public void setExtraElementen(ExtraElementen value) {
        this.extraElementen = value;
    }

    /**
     * Gets the value of the soortEntiteit property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSoortEntiteit() {
        if (soortEntiteit == null) {
            return "R";
        } else {
            return soortEntiteit;
        }
    }

    /**
     * Sets the value of the soortEntiteit property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSoortEntiteit(String value) {
        this.soortEntiteit = value;
    }

    /**
     * Gets the value of the sleutelVerzendend property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSleutelVerzendend() {
        return sleutelVerzendend;
    }

    /**
     * Sets the value of the sleutelVerzendend property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSleutelVerzendend(String value) {
        this.sleutelVerzendend = value;
    }

    /**
     * Gets the value of the sleutelOntvangend property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSleutelOntvangend() {
        return sleutelOntvangend;
    }

    /**
     * Sets the value of the sleutelOntvangend property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSleutelOntvangend(String value) {
        this.sleutelOntvangend = value;
    }

    /**
     * Gets the value of the sleutelGegevensbeheer property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSleutelGegevensbeheer() {
        return sleutelGegevensbeheer;
    }

    /**
     * Sets the value of the sleutelGegevensbeheer property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSleutelGegevensbeheer(String value) {
        this.sleutelGegevensbeheer = value;
    }

    /**
     * Gets the value of the verwerkingssoort property.
     * 
     * @return
     *     possible object is
     *     {@link Verwerkingssoort }
     *     
     */
    public Verwerkingssoort getVerwerkingssoort() {
        return verwerkingssoort;
    }

    /**
     * Sets the value of the verwerkingssoort property.
     * 
     * @param value
     *     allowed object is
     *     {@link Verwerkingssoort }
     *     
     */
    public void setVerwerkingssoort(Verwerkingssoort value) {
        this.verwerkingssoort = value;
    }

    /**
     * Gets the value of the noValue property.
     * 
     * @return
     *     possible object is
     *     {@link NoValue }
     *     
     */
    public NoValue getNoValue() {
        return noValue;
    }

    /**
     * Sets the value of the noValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link NoValue }
     *     
     */
    public void setNoValue(NoValue value) {
        this.noValue = value;
    }

}

==> brmo-stufbg204-2.0.1-sources.jar: nl/egem/stuf/sector/bg/_0204/Relatie.java <==

package nl.egem.stuf.sector.bg._0204;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import nl.egem.stuf.stuf0204.ExtraElementen;
import nl.egem.stuf.stuf0204.NoValue;
import nl.egem.stuf.stuf0204.TijdvakGeldigheid;
import nl.egem.stuf.stuf0204.TijdvakRelatie;
import nl.egem.stuf.stuf0204.Verwerkingssoort;


/**
 * generieke relatie-entiteit zonder elementen
 * 
 * <p>Java class for Relatie complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="Relatie"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="tijdvakRelatie" type="{http://www.egem.nl/StUF/StUF0204}TijdvakRelatie" minOccurs="0"/&gt;
 *         &lt;element name="tijdvakGeldigheid" type="{http://www.egem.nl/StUF/StUF0204}TijdvakGeldigheid" minOccurs="0"/&gt;
 *         &lt;element name="extraElementen" type="{http://www.egem.nl/StUF/StUF0204}ExtraElementen" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}relatie"/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Relatie", propOrder = {
    "tijdvakRelatie",
    "tijdvakGeldigheid",
    "extraElementen"
})
@XmlSeeAlso({
    ADRRelFund.class,
    nl.egem.stuf.sector.bg._0204.HHDKennisgeving.HDDWOZ.class,
    nl.egem.stuf.sector.bg._0204.HHDVraag.HDDWOZ.class,
    nl.egem.stuf.sector.bg._0204.HHDAntwoord.HDDWOZ.class,
    nl.egem.stuf.sector.bg._0204.KDOKennisgeving.KDOBSG.class,
    nl.egem.stuf.sector.bg._0204.KDOKennisgeving.KDOPRB.class,
    nl.egem.stuf.sector.bg._0204.KDOKennisgeving.KDOSUBVZG.class,
    nl.egem.stuf.sector.bg._0204.KDOVraag.KDOBSG.class,
    nl.egem.stuf.sector.bg._0204.KDOVraag.KDOPRB.class,
    nl.egem.stuf.sector.bg._0204.KDOVraag.KDOSUBVZG.class,
    nl.egem.stuf.sector.bg._0204.KDOAntwoord.KDOBSG.class,
    nl.egem.stuf.sector.bg._0204.KDOAntwoord.KDOPRB.class,
    nl.egem.stuf.sector.bg._0204.KDOAntwoord.KDOSUBVZG.class,
    nl.egem.stuf.sector.bg._0204.NNPKennisgeving.NNPNNPHFD.class,
    nl.egem.stuf.sector.bg._0204.NNPKennisgeving.NNPNNPNVN.class,
    nl.egem.stuf.sector.bg._0204.NNPVraag.NNPNNPHFD.class,
    nl.egem.stuf.sector.bg._0204.NNPVraag.NNPNNPNVN.class,
    nl.egem.stuf.sector.bg._0204.NNPAntwoord.NNPNNPHFD.class,
    nl.egem.stuf.sector.bg._0204.NNPAntwoord.NNPNNPNVN.class,
    nl.egem.stuf.sector.bg._0204.OBWKennisgeving.OBWKDO.class,
    nl.egem.stuf.sector.bg._0204.OBWKennisgeving.OBWBSG.class,
    nl.egem.stuf.sector.bg._0204.OBWVraag.OBWKDO.class,
    nl.egem.stuf.sector.bg._0204.OBWVraag.OBWBSG.class,
    nl.egem.stuf.sector.bg._0204.OBWAntwoord.OBWKDO.class,
    nl.egem.stuf.sector.bg._0204.OBWAntwoord.OBWBSG.class,
    nl.egem.stuf.sector.bg._0204.VBOKennisgeving.VBOBSG.class,
    nl.egem.stuf.sector.bg._0204.VBOKennisgeving.VBOKDO.class,
    nl.egem.stuf.sector.bg._0204.VBOKennisgeving.VBOSUBGBR.class,
    nl.egem.stuf.sector.bg._0204.VBOVraag.VBOBSG.class,
    nl.egem.stuf.sector.bg._0204.VBOVraag.VBOKDO.class,
    nl.egem.stuf.sector.bg._0204.VBOVraag.VBOSUBGBR.class,
    nl.egem.stuf.sector.bg._0204.VBOAntwoord.VBOBSG.class,
    nl.egem.stuf.sector.bg._0204.VBOAntwoord.VBOKDO.class,
    nl.egem.stuf.sector.bg._0204.VBOAntwoord.VBOSUBGBR.class,
    ADRRelKerngegevens.class,
    nl.egem.stuf.sector.bg._0204.WOZKennisgeving.WOZKDO.class,
    nl.egem.stuf.sector.bg._0204.WOZKennisgeving.WOZOBW.class,
    nl.egem.stuf.sector.bg._0204.WOZKennisgeving.WOZSUBEIG.class,
    nl.egem.stuf.sector.bg._0204.WOZKennisgeving.WOZSUBGBR.class,
    nl.egem.stuf.sector.bg._0204.WOZKennisgeving.WOZVBO.class,
    nl.egem.stuf.sector.bg._0204.WOZVraag.WOZKDO.class,
    nl.egem.stuf.sector.bg._0204.WOZVraag.WOZOBW.class,
    nl.egem.stuf.sector.bg._0204.WOZVraag.WOZSUBEIG.class,
    nl.egem.stuf.sector.bg._0204.WOZVraag.WOZSUBGBR.class,
    nl.egem.stuf.sector.bg._0204.WOZVraag.WOZVBO.class,
    nl.egem.stuf.sector.bg._0204.WOZAntwoord.WOZKDO.class,
    nl.egem.stuf.sector.bg._0204.WOZAntwoord.WOZOBW.class,
    nl.egem.stuf.sector.bg._0204.WOZAntwoord.WOZSUBEIG.class,
    nl.egem.stuf.sector.bg._0204.WOZAntwoord.WOZSUBGBR.class,
    nl.egem.stuf.sector.bg._0204.WOZAntwoord.WOZVBO.class
})
public class Relatie {

    protected TijdvakRelatie tijdvakRelatie;
    protected TijdvakGeldigheid tijdvakGeldigheid;
    protected ExtraElementen extraElementen;
    @XmlAttribute(name = "soortEntiteit", required = true)
    protected String soortEntiteit;
    @XmlAttribute(name = "sleutelVerzendend", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected String sleutelVerzendend;
    @XmlAttribute(name = "sleutelOntvangend", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected String sleutelOntvangend;
    @XmlAttribute(name = "sleutelGegevensbeheer", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected String sleutelGegevensbeheer;
    @XmlAttribute(name = "verwerkingssoort", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected Verwerkingssoort verwerkingssoort;
    @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected NoValue noValue;

    /**
     * Gets the value of the tijdvakRelatie property.
     * 
     * @return
     *     possible object is
     *     {@link TijdvakRelatie }
     *     
     */
    public TijdvakRelatie getTijdvakRelatie() {
        return tijdvakRelatie;
    }

    /**
     * Sets the value of the tijdvakRelatie property.
     * 
     * @param value
     *     allowed object is
     *     {@link TijdvakRelatie }
     *     
     */
    public void setTijdvakRelatie(TijdvakRelatie value) {
        this.tijdvakRelatie = value;
    }

    /**
     * Gets the value of the tijdvakGeldigheid property.
     * 
     * @return
     *     possible object is
     *     {@link TijdvakGeldigheid }
     *     
     */
    public TijdvakGeldigheid getTijdvakGeldigheid() {
        return tijdvakGeldigheid;
    }

    /**
     * Sets the value of the tijdvakGeldigheid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TijdvakGeldigheid }
     *     
     */
    public void setTijdvakGeldigheid(TijdvakGeldigheid value) {
        this.tijdvakGeldigheid = value;
    }

    /**
     * Gets the value of the extraElementen property.
     * 
     * @return
     *     possible object is
     *     {@link ExtraElementen }
     *     
     */
    public ExtraElementen getExtraElementen() {
        return extraElementen;
    }

    /**
     * Sets the value of the extraElementen property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtraElementen }
     *     
     */
    public void setExtraElementen(ExtraElementen value) {
        this.extraElementen = value;
    }

    /**
     * Gets the value of the soortEntiteit property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSoortEntiteit() {
        if (soortEntiteit == null) {
            return "R";
        } else {
            return soortEntiteit;
        }
    }

    /**
     * Sets the value of the soortEntiteit property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSoortEntiteit(String value) {
        this.soortEntiteit = value;
    }

    /**
     * Gets the value of the sleutelVerzendend property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSleutelVerzendend() {
        return sleutelVerzendend;
    }

    /**
     * Sets the value of the sleutelVerzendend property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSleutelVerzendend(String value) {
        this.sleutelVerzendend = value;
    }

    /**
     * Gets the value of the sleutelOntvangend property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSleutelOntvangend() {
        return sleutelOntvangend;
    }

    /**
     * Sets the value of the sleutelOntvangend property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSleutelOntvangend(String value) {
        this.sleutelOntvangend = value;
    }

    /**
     * Gets the value of the sleutelGegevensbeheer property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSleutelGegevensbeheer() {
        return sleutelGegevensbeheer;
    }

    /**
     * Sets the value of the sleutelGegevensbeheer property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSleutelGegevensbeheer(String value) {
        this.sleutelGegevensbeheer = value;
    }

    /**
     * Gets the value of the verwerkingssoort property.
     * 
     * @return
     *     possible object is
     *     {@link Verwerkingssoort }
     *     
     */
    public Verwerkingssoort getVerwerkingssoort() {
        return verwerkingssoort;
    }

    /**
     * Sets the value of the verwerkingssoort property.
     * 
     * @param value
     *     allowed object is
     *     {@link Verwerkingssoort }
     *     
     */
    public void setVerwerkingssoort(Verwerkingssoort value) {
        this.verwerkingssoort = value;
    }

    /**
     * Gets the value of the noValue property.
     * 
     * @return
     *     possible object is
     *     {@link NoValue }
     *     
     */
    public NoValue getNoValue() {
        return noValue;
    }

    /**
     * Sets the value of the noValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link NoValue }
     *     
     */
    public void setNoValue(NoValue value) {
        this.noValue = value;
    }

}
